# Copyright (c) 2017 by Uncled1023 <admin@teknik.io>
#
# License BSD 3-Clause

# Base Libraries
import base64
import json

# Local Libraries
from . import util

# Dependencies
import requests

# Main Functions
def UploadFile(url, filePath, username, authToken):  
  files = {'file': open(filePath, "rb")}
  
  if url is None:
    url = util.defaultUrl
  
  if username is None:
    username = util.defaultUsername
  
  if authToken is None:
    authToken = util.defaultToken
  
  # Create a header if they have added auth info
  headers = {}
  if username != '' and authToken != '':
    encAuth = base64.b64encode(username + ':' + authToken)
    headers = {'Authorization': 'Basic ' + encAuth}
  
  r = requests.post(util.GetUrl(url, 'upload'), files=files, headers=headers)
  jObj = json.loads(r.text)
  
  return jObj


try:
  from urllib.parse import urljoin
except ImportError as e:
  from urlparse import urljoin

defaultUrl = 'https://api.teknik.io/v1/'
defaultUsername = ''
defaultToken = ''

def GetUrl(url, service):
  finalUrl = ''
  
  if url is None or url == '':
    url = defaultUrl

  server = service.lower()
  if service == 'upload':
    finalUrl = urljoin(url, 'Upload')
  elif service == 'paste':
    finalUrl = urljoin(url, 'Paste')
  
  return finalUrl